Set (imandrax-ocaml.Imandrax_ocaml_prelude.Prelude_extracted.Set)

`type +'a t = ('a, bool) Map.t`
`val empty_ : ('a, bool) Map.t`
`val empty : 'a t`
`val full_ : ('a, bool) Map.t`
`val full : 'a t`
`val is_empty : 'a t -> bool`
`val is_valid : 'a t -> bool`
`val mem : 'a -> 'a t -> bool`
`val subset_ : ('a, bool) Map.t -> 'a t -> bool`

Checks if `s1` is a subset of `s2`

`val subset : 'a t -> 'a t -> bool`
`val add_ : 'a -> ('a, bool) Map.t -> ('a, bool) Map.t`
`val add : 'a -> 'a t -> 'a t`
`val remove_ : 'a -> ('a, bool) Map.t -> ('a, bool) Map.t`
`val remove : 'a -> 'a t -> 'a t`
`val inter_ : 'a t -> 'a t -> 'a t`
`val inter : 'a t -> 'a t -> 'a t`
`val union_ : 'a t -> 'a t -> 'a t`
`val union : 'a t -> 'a t -> 'a t`
`val complement_ : 'a t -> 'a t`
`val complement : 'a t -> 'a t`
`val diff_ : 'a t -> 'a t -> 'a t`
`val diff : 'a t -> 'a t -> 'a t`
`val of_list : 'a list -> 'a t`
`val to_list : 'a t -> 'a list`
`val (++) : 'a t -> 'a t -> 'a t`
`val (--) : 'a t -> 'a t -> 'a t`
`val pp : (Stdlib.Format.formatter -> 'a -> unit) -> Stdlib.Format.formatter -> 'a t -> unit`